@@ -6,10 +6,11 @@ use warnings;
 use Getopt::Long;
 use lib 'lib';
 use Params::Util qw( _HASH );
-use JSON::XS ();
+#use JSON::XS ();
+use JSON::Syck;
 use WWW::OpenResty::Simple;
 use Data::Dumper;
-use Data::Structure::Util qw(_utf8_off);
+use Data::Structure::Util qw(_utf8_on _utf8_off);
 
 sub usage {
     my $progname;
@@ -59,7 +60,7 @@ if ($help) { print usage() }
 $user or die "No --user given.\n";
 $model or die "No --model given.\n";
 
-my $json_xs = JSON::XS->new->utf8->allow_nonref;
+# my $json_xs = JSON::XS->new->utf8->allow_nonref;
 
 my $openresty = WWW::OpenResty::Simple->new(
     { server => $server, retries => $retries, ignore_dup_error => $ignore_dup_error }
@@ -76,7 +77,9 @@ while (<>) {
     #select(undef, undef, undef, 0.1);
     #warn "count: ", scalar(@elems), "\n";
     next if $. <= $skip;
-    my $row = $json_xs->decode($_);
+    # my $row = $json_xs->decode($_);
+    my $row = JSON::Syck::Load($_);
+
 
     if (!defined $row->{id}) {
         #warn "ADDing id...\n";
@@ -109,6 +112,7 @@ sub insert_rows {
         };
         if ($@) { warn $@, "\n" };
     }
+    _utf8_on($rows);
     eval {
         $res = $openresty->post(
             "/=/model/$model/~/~",
@@ -116,7 +120,8 @@ sub insert_rows {
         );
     };
     if ($@ || !_HASH($res)) {
-        die "Around line $.: $@", (defined $res ? $json_xs->encode($res) : $res);
+        #die "Around line $.: $@", (defined $res ? $json_xs->encode($res) : $res);
+        die "Around line $.: $@", (defined $res ? JSON::Syck::Dump($res) : $res);
         return 0;
     }
     #warn Dumper($res);
